{**
 * This unit contain the GUI and the logic of the application
 *
 * All this code is under <a href="http://www.gnu.org/copyleft/gpl.html">GNU General Public License</a>
 * @Author <a href="mailto:jolly_arnaud@yahoo.fr">JOLLY Arnaud</a>
 * @version 0.6.0
 *}

{
    JOLLY Arnaud software designer
    Copyright (C) 2006 JOLLY Arnaud

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
}
unit ImageHoverBtn;

interface

uses
  SysUtils, Classes, Controls, ExtCtrls, QControls, Graphics;

type
  {**
   * Create the TImage to create a two state button.
   * Enable toControle the MouseIn and MouseOutEvent
   *}
  TImageHoverBtn = class(TImage)
  private
    { Dclarations prives }
    FOnMouseLeaveImage: TNotifyEvent; ///Event when mouse go out of the component
    FOnMouseEnterImage: TNotifyEvent; ///Event when the mouse enter in teh component
    FPictureNorm       : TBitmap;     ///Standard picture of the button
    FPictureHover      : TBitmap;     ///Hover picture of the bouton (when the mouse is in the button)
    procedure CMMouseEnter(var msg: TMessage); message CM_MOUSEENTER; ///Intercept the windows mouseover event
    procedure CMMouseLeave(var msg: TMessage); message CM_MOUSELEAVE; ///Intercept the windows mouseover event
    procedure SetPictureNorm(Value: TBitmap);
    procedure SetPictureHover(Value: TBitmap);
  protected
    { Dclarations protges }
  public
    { Dclarations publiques }
  published
    { Dclarations publies }
    constructor Create(Owner: TComponent); override;
    destructor Destroy(); override;
    property OnEnter      : TNotifyEvent read FOnMouseEnterImage write FOnMouseEnterImage; ///User event to launch when mouse enter in the TImage
    property OnLeave      : TNotifyEvent read FOnMouseLeaveImage write FOnMouseLeaveImage; ///User event to launch when mouse leave the TImage
    property PictureNorm  : TBitmap  read FPictureNorm write SetPictureNorm;      ///Picture contain the normal state image (mouse out)
    property PictureHover : TBitmap  read FPictureHover write SetPictureHover;    ///Picture contain the hover state image (mouse in)
  end;

procedure Register;

implementation
{**
 * Register the TImageHoverBtn in the standard bar of delphi 7
 *}
procedure Register;
begin
  RegisterComponents('Standard', [TImageHoverBtn]);
end;

{**
 * Create the two images for the button
 * @param Owner Owner component of the TImageHoverBtn
 *}
constructor TImageHoverBtn.Create(Owner: TComponent);
begin
  inherited Create(Owner);
  FPictureNorm   := TBitmap.Create();
  FPictureHover  := TBitmap.Create();
end;

{**
 * Free the bitmap created on create and launch the deffault destroy method
 *}
destructor TImageHoverBtn.Destroy();
begin
  FPictureNorm.free;
  FPictureHover.free;
  inherited Destroy();
end;

{**
 * Change the image if image hover and enter set and launch the onEnterEvent
 * @param msg standard windows Msg
 *}
procedure TImageHoverBtn.CMMouseEnter(var msg: TMessage);
begin
  if Assigned(FPictureHover) and Assigned(FPictureNorm) then
    Picture.Bitmap.Assign(FPictureHover);
  if Assigned(OnEnter)then OnEnter(self);
end;

{**
 * Change the image if image hover and enter set and launch the onEnterEvent
 * @param msg standard windows Msg
 *}
procedure TImageHoverBtn.CMMouseLeave(var msg: TMessage);
begin
  if Assigned(FPictureHover) and Assigned(FPictureNorm) then
    Picture.Bitmap.Assign(FPictureNorm);
  if Assigned(OnLeave)then OnLeave(self);
end;

{**
 * Code to set the deffault picture of the button
 * @param Value Bitmap that contain the deffault button image
 *}
procedure TImageHoverBtn.SetPictureNorm(Value: TBitmap);
begin
  FPictureNorm.Assign(Value);
end;

{**
 * Code to set the hover picture of the button
 * @param Value Bitmap that contain the Hover button image
 *}
procedure TImageHoverBtn.SetPictureHover(Value: TBitmap);
begin
  FPictureHover.Assign(Value);
end;


end.
