{**
 * This unit the function to obtain size in comptuer unit on a drive
 *
 * All this code is under <a href="http://www.gnu.org/copyleft/gpl.html">GNU General Public License</a>
 * @Author <a href="mailto:jolly_arnaud@yahoo.fr">JOLLY Arnaud</a>
 * @version 0.6.0
 *}

{
    JOLLY Arnaud software designer
    Copyright (C) 2006 JOLLY Arnaud

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
}
unit SizeFunction;

interface
  function getSizeBase  (DiskSize : Int64) : integer;
  function getSizeUnit  (Base : integer) : String;
  function getSizeValue (Size : Int64; Base : integer) : Int64;
implementation
  {**
   * return the base to use for calculate the size of a device
   * @param DiskSize size of the disk in octets
   * @return base of the data (for getSizeUnit and getSizeValue function)
   *}
  function getSizeBase  (DiskSize : Int64) : integer;
  var
    i : integer;
  begin
    i:=0;
    while DiskSize > 1024 do
    begin
      DiskSize := round(DiskSize / 1024);
      inc(i);
    end;
    if i > 4 then
      result := 4
    else if i < 1 then
      result := 0
    else
      result := i - 1;
  end;

  {**
   * this function return string that contain the size unit of a base
   * calculated by getSizeBase
   * @param Base Base size return by getSizeBase
   * @return the base to use for calculate the size of a device
   *}
  function getSizeUnit  (Base : integer) : String;
  begin
    if Base = 0 then
      result := 'octets'
    else if Base = 1 then
      result := 'Ko'
    else if Base = 2 then
      result := 'Mo'
    else if Base = 3 then
      result := 'Go'
    else if Base = 4 then
      result := 'To'
    else
      result := '';
  end;

  {**
   * return the size of a drive for a base return by getSizeBase
   * @param Size size of the drive to convert
   * @param Base Base size return by getSizeBase
   * @return size in base unit
   *}
  function getSizeValue (Size : Int64; Base : integer) : Int64;
  var
    i : integer;
    BaseSize : int64;
  begin
    BaseSize := 1;
    if Base > 0 then
      for i:=1 to Base do
        BaseSize := BaseSize * 1024;
    result := round(Size / BaseSize);
  end;
end.
 